@@ -95,7 +95,7 @@ class WorkerSettings:
         self.database = settings.database
         self.show_skipped = settings.show_skipped
         self.show_retries = settings.show_retries
-        self.trim = settings.trim
+        self.trim_results = settings.trim_results
         self.random_order = settings.random_order
         self.service_timeout = settings.service_timeout
         self.global_thread_pool = (
@@ -107,6 +107,7 @@ class WorkerSettings:
                 settings.global_async_pool.initargs
             ) if settings.global_async_pool is not None else None
         self.global_process_pool = self._set_service_object(settings.global_process_pool)
+        self.secrets_registry = settings.secrets_registry
 
     def _set_service_object(self, obj):
         if obj is None:
@@ -152,7 +153,7 @@ class _WorkItem(object):
             settings.database = work_settings.database
             settings.show_skipped = work_settings.show_skipped
             settings.show_retries = work_settings.show_retries
-            settings.trim = work_settings.trim
+            settings.trim_results = work_settings.trim_results
             settings.random_order = work_settings.random_order
             settings.service_timeout = work_settings.service_timeout
             # set global thread pool
@@ -167,6 +168,7 @@ class _WorkItem(object):
                 settings.global_async_pool = cls(*initargs)
             # set shared global process pool
             settings.global_process_pool = work_settings.global_process_pool
+            settings.secrets_registry = work_settings.secrets_registry
 
         def runner(self):
             try:
@@ -176,7 +178,7 @@ class _WorkItem(object):
                     current(self.current_test)
 
                     set_settings(self.settings)
-                    
+
                     # global thread and async pool are local to each work item
                     with (settings.global_thread_pool or contextlib.nullcontext()), (
                             settings.global_async_pool or contextlib.nullcontext()):
@@ -226,8 +228,8 @@ class WorkerProtocol(asyncio.SubprocessProtocol):
     def pipe_data_received(self, fd, data):
         if not self.ready_future.done() and data:
             self.buffer += self.decoder.decode(data)
-            if self.buffer.startswith(WORKER_READY):
-                data = self.buffer[len(WORKER_READY):]
+            if WORKER_READY in self.buffer:
+                data = self.buffer.split(WORKER_READY, 1)[-1]
                 self.ready_future.set_result(True)
 
         elif data:
